doublemetaphone

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2019 License: Artistic-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DoubleMetaphone

func DoubleMetaphone(str string) (string, string)

DoubleMetaphone computes the primary and secondary Metaphone of the given string. The original string is not modified by the function

Types

This section is empty.

Jump to